@@ -9,7 +9,7 @@ Path::Resource - URI/Path::Class combination.
 
 =head1 VERSION
 
-Version 0.042
+Version 0.05
 
 =head1 SYNOPSIS
 
@@ -35,15 +35,15 @@ Version 0.042
 
 =cut
 
-our $VERSION = '0.042';
+our $VERSION = '0.05';
 
 use Path::Class();
 use Path::Resource::Base();
 use Path::Abstract;
-use Scalar::Util qw(blessed);
+use Scalar::Util qw/blessed/;
 use Carp;
-use base qw/Class::Accessor/;
-__PACKAGE__->mk_accessors(qw(path base));
+use base qw/Class::Accessor::Fast/;
+__PACKAGE__->mk_accessors(qw(_path base));
 
 =over 4
 
@@ -88,74 +88,129 @@ sub new {
 	$self->base($base);
 
         $path = Path::Abstract->new($path) unless blessed $path && $path->isa("Path::Abstract");
-	$self->path($path);
+	$self->_path($path);
 
 	return $self;
 }
 
-=item $rsc->file
+=item $rsc->path
+
+=item $rsc->path( <part>, [ <part>, ..., <part> ] )
+
+Return a clone of $rsc->path based on $rsc->path and any optional <part> passed through
+
+    my $rsc = Path::Resource->new(path => "b/c");
+
+    # $path is "b/c"
+    my $path = $rsc->path;
+
+    # $path is "b/c/d"
+    my $path = $rsc->path("d");
 
 =cut
 
-sub file {
+sub path {
 	my $self = shift;
-	unshift @_, $self->path->get unless $self->path->is_empty;
-	return $self->base->dir->file(@_);
-}
-
-=item $rsc->dir
-
-=cut
-
-sub dir {
-	my $self = shift;
-	unshift @_, $self->path->get unless $self->path->is_empty;
-	return $self->base->dir->subdir(@_);
+    my $path = $self->_path->child(@_);
+    return $path;
 }
 
 =item $rsc->clone
 
+=item $rsc->clone( <path> )
+
+Return a Path::Resource object that is a copy of $rsc
+
+The optional argument will change (not append) the path of the cloned object
+
 =cut
 
 sub clone {
 	my $self = shift;
-	my $path = shift || $self->path->clone;
+	my $path = shift || $self->_path->clone;
 	return __PACKAGE__->new(base => $self->base->clone, path => $path);
 }
 
-=item $rsc->child
+=item $rsc->child( <part>, [ <part>, ..., <part> ] )
+
+Return a clone Path::Resource object whose path is the child of $rsc->path
+
+    my $rsc = Path::Resource->new(dir => "/a", path => "b");
+
+    # $rsc->path is "b/c/d.tmp"
+    $rsc = $rsc->child("c/d.tmp");
 
 =cut
 
 sub child {
 	my $self = shift;
-	my $clone = $self->clone($self->path->child(@_));
+	my $clone = $self->clone($self->_path->child(@_));
 	return $clone;
 }
 
 =item $rsc->parent
 
+Return a clone Path::Resource object whose path is the parent of $rsc->path
+
+    my $rsc = Path::Resource->new(dir => "/a", path => "b/c");
+
+    # $rsc->path is "b"
+    $rsc = $rsc->parent;
+
+    # $rsc->path is ""
+    $rsc = $rsc->parent;
+
+    # $dir is "/a/f"
+    my $dir = $rsc->parent->parent->dir("f");
+
 =cut
 
 sub parent {
 	my $self = shift;
-	my $clone = $self->clone($self->path->parent);
+	my $clone = $self->clone($self->_path->parent);
 	return $clone;
 }
 
 =item $rsc->loc
 
+=item $rsc->loc( <part>, [ <part>, ..., <part> ] )
+
+Return a Path::Abstract object based on the path part of $rsc->base->uri ($rsc->base->loc), $rsc->path, and any optional <part> passed through
+
+    my $rsc = Path::Resource->new(uri => "http://example.com/a", path => "b/c");
+
+    # $loc is "/a/b/c"
+    my $loc = $rsc->loc;
+
+    # $dir is "/a/b/c/d.tmp"
+    $loc = $rsc->loc("d.tmp");
+
 =cut
 
 sub loc {
 	my $self = shift;
-	unshift @_, $self->path unless $self->path->is_empty;
+	unshift @_, $self->_path unless $self->_path->is_empty;
 	return $self->base->loc->child(@_);
 }
 
 
 =item $rsc->uri
 
+=item $rsc->uri( <part>, [ <part>, ..., <part> ] )
+
+Return a URI object based on $rsc->base->uri, $rsc->path, and any optional <part> passed through
+
+    my $rsc = Path::Resource->new(uri => "http://example.com/a", path => "b/c");
+
+    # $uri is "http://example.com/a/b/c"
+    my $uri = $rsc->uri;
+
+    # $uri is "http://example.com/a/b/c/d.tmp"
+    $uri = $rsc->uri("d.tmp");
+
+    # $uri is "https://example.com/a/b/c/d.tmp"
+    $uri->scheme("https");
+
 =cut
 
 sub uri {
@@ -165,10 +220,57 @@ sub uri {
 	return $uri;
 }
 
-=item $rsc->path
+=item $rsc->file
+
+=item $rsc->file( [ <part>, <part>, ..., <part> ] )
+
+Return a Path::Class::File object based on $rsc->base->dir, $rsc->path, and any optional <part> passed through
+
+    my $rsc = Path::Resource->new(dir => "/a", path => "b");
+    $rsc = $rsc->child("c/d.tmp");
+
+    # $file is "/a/b/c/d.tmp"
+    my $file = $rsc->file;
+
+    # $file is "/a/b/c/d.tmp/e.txt"
+    $file = $rsc->file(qw/ e.txt /);
+
+=cut
+
+sub file {
+	my $self = shift;
+	unshift @_, $self->_path->get unless $self->_path->is_empty;
+	return $self->base->dir->file(@_);
+}
+
+=item $rsc->dir
+
+=item $rsc->dir( <part>, [ <part>, ..., <part> ] )
+
+Return a Path::Class::Dir object based on $rsc->base->dir, $rsc->path, and any optional <part> passed through
+
+    my $rsc = Path::Resource->new(dir => "/a", path => "b");
+    $rsc = $rsc->child("c/d.tmp");
+
+    # $dir is "/a/b/c/d.tmp"
+    my $dir = $rsc->file;
+
+    # $dir is "/a/b/c/d.tmp/e.tmp"
+    $dir = $rsc->file(qw/ e.tmp /);
+
+=cut
+
+sub dir {
+	my $self = shift;
+	unshift @_, $self->_path->get unless $self->_path->is_empty;
+	return $self->base->dir->subdir(@_);
+}
+
 
 =item $rsc->base
 
+Return the Path::Resource::Base object for $rsc
+
 =back 
 
 =head1 AUTHOR
